summary refs log tree commit diff
path: root/libnm-util/nm-setting-wireless-security.c
diff options
context:
space:
mode:
Diffstat (limited to 'libnm-util/nm-setting-wireless-security.c')
-rw-r--r--libnm-util/nm-setting-wireless-security.c46
1 files changed, 26 insertions, 20 deletions
diff --git a/libnm-util/nm-setting-wireless-security.c b/libnm-util/nm-setting-wireless-security.c
index 5dec266f..9e4becca 100644
--- a/libnm-util/nm-setting-wireless-security.c
+++ b/libnm-util/nm-setting-wireless-security.c
@@ -1301,38 +1301,44 @@ nm_setting_wireless_security_class_init (NMSettingWirelessSecurityClass *setting
 	/**
 	 * NMSettingWirelessSecurity:pairwise:
 	 *
 	 * If specified, will only connect to WPA networks that provide the
 	 * specified pairwise encryption capabilities.  Each element may be one of
 	 * 'wep40', 'wep104', 'tkip', or 'ccmp'.
 	 **/
 	g_object_class_install_property
 		(object_class, PROP_PAIRWISE,
 		 _nm_param_spec_specialized (NM_SETTING_WIRELESS_SECURITY_PAIRWISE,
-							   "Pairwise",
-							   "If specified, will only connect to WPA networks "
-							   "that provide the specified pairwise encryption "
-							   "capabilities.  Each element may be one of 'wep40', "
-							   "'wep104', 'tkip', or 'ccmp'.",
-							   DBUS_TYPE_G_LIST_OF_STRING,
-							   G_PARAM_READWRITE | NM_SETTING_PARAM_SERIALIZE));
+		                       "Pairwise",
+		                       "A list of pairwise encryption algorithms which "
+		                       "prevents connections to Wi-Fi networks that do "
+		                       "not utilize one of the algorithms in the list. "
+		                       "For maximum compatibility leave this property "
+		                       "empty.  Each list element may be one of 'wep40', "
+		                       "'wep104', 'tkip' or 'ccmp'.",
+		                       DBUS_TYPE_G_LIST_OF_STRING,
+		                       G_PARAM_READWRITE | NM_SETTING_PARAM_SERIALIZE));
 
 	/**
 	 * NMSettingWirelessSecurity:group:
 	 *
-	 * If specified, will only connect to WPA networks that provide the
-	 * specified group/multicast encryption capabilities.  Each element may be
-	 * one of 'wep40', 'wep104', 'tkip', or 'ccmp'.
+	 * A list of group/broadcast encryption algorithms which prevents
+	 * connections to Wi-Fi networks that do not utilize one of the algorithms
+	 * in the list.  For maximum compatibility leave this property empty.  Each
+	 * list element may be one of 'wep40', 'wep104', 'tkip', or 'ccmp'.
 	 **/
 	g_object_class_install_property
 		(object_class, PROP_GROUP,
 		 _nm_param_spec_specialized (NM_SETTING_WIRELESS_SECURITY_GROUP,
-							   "Group",
-							   "If specified, will only connect to WPA networks "
-							   "that provide the specified group/multicast "
-							   "encryption capabilities.  Each element may be "
-							   "one of 'wep40', 'wep104', 'tkip', or 'ccmp'.",
-							   DBUS_TYPE_G_LIST_OF_STRING,
-							   G_PARAM_READWRITE | NM_SETTING_PARAM_SERIALIZE));
+		                       "Group",
+		                       "A list of group/broadcast encryption algorithms "
+		                       "which prevents connections to Wi-Fi networks "
+		                       "that do not utilize one of the algorithms in "
+		                       "the list.  For maximum compatibility leave this "
+		                       "property empty.  Each list element may be one "
+		                       " of 'wep40', 'wep104', 'tkip', or 'ccmp'.",
+		                       DBUS_TYPE_G_LIST_OF_STRING,
+		                       G_PARAM_READWRITE | NM_SETTING_PARAM_SERIALIZE));
 
 	/**
 	 * NMSettingWirelessSecurity:leap-username:
@@ -1301,38 +1301,44 @@ nm_setting_wireless_security_class_init (NMSettingWirelessSecurityClass *setting
 	 * NMSettingWirelessSecurity:pairwise:
 	 *
-	 * If specified, will only connect to WPA networks that provide the
-	 * specified pairwise encryption capabilities.  Each element may be one of
-	 * 'wep40', 'wep104', 'tkip', or 'ccmp'.
+	 * A list of pairwise encryption algorithms which prevents connections to
+	 * Wi-Fi networks that do not utilize one of the algorithms in the list.  For
+	 * maximum compatibility leave this property empty.  Each list element may
+	 * be one of 'wep40', 'wep104', 'tkip', or 'ccmp'.
 	 **/
 	g_object_class_install_property